@@ -35,7 +35,6 @@ def sync_algorithm(
     id: Optional[str]=None,
     name: Optional[str]=None,
     dir_path: Optional[Union[str, Path]]=None,
-    archive_path: Optional[str]=None, # deprecated in 0.11.11, remove in 0.12.3
     entrypoint_training: Optional[str]=None,
     output_training: Optional[str]=None,
     mirror_name: Optional[str]="QUICKSTART",
@@ -51,15 +50,6 @@ def sync_algorithm(
             image_name=mirror_name,
         )
     else:
-        deprecated = {
-            'archive_path': archive_path,
-        }
-        for k, v in deprecated.items():
-            if v:
-                logger.warning(
-                    f"Parameter `{k}` is deprecated since 0.11.11 "
-                    "and will be removed in 0.12.3."
-                )
         return _sync_local_algorithm(
             name=name,
             dir_path=dir_path,
